@@ -7,10 +7,11 @@ package    # hide from PAUSE
 BEGIN {
     require DBIx::Squirrel
       unless defined($DBIx::Squirrel::VERSION);
+    require Exporter;
     $DBIx::Squirrel::Transform::YAML::Syck::VERSION   = $DBIx::Squirrel::VERSION;
     @DBIx::Squirrel::Transform::YAML::Syck::ISA       = qw/Exporter/;
-    @DBIx::Squirrel::Transform::YAML::Syck::EXPORT    = qw/as_yaml/;
     @DBIx::Squirrel::Transform::YAML::Syck::EXPORT_OK = qw/as_yaml/;
+    @DBIx::Squirrel::Transform::YAML::Syck::EXPORT    = @DBIx::Squirrel::Transform::YAML::Syck::EXPORT_OK;
 }
 
 use YAML::Syck;
@@ -20,7 +21,7 @@ sub as_yaml {
         local($YAML::Syck::ImplicitTyping)  = !!1;
         local($YAML::Syck::ImplicitUnicode) = !!1;
         local($YAML::Syck::SortKeys)        = !!1;
-        return YAML::Syck::Dump(shift);
+        return YAML::Syck::Dump(@_);
     };
 }
 
